.. currentmodule:: sardana.pool.controller

:mod:`~sardana.pool.controller`
===============================

.. automodule:: sardana.pool.controller

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`Controller`
    * :class:`Readable`
    * :class:`Startable`
    * :class:`PseudoController`
    * :class:`MotorController`
    * :class:`PseudoMotorController`
    * :class:`CounterTimerController`
    * :class:`PseudoCounterController`
    * :class:`IORegisterController`
    
Controller
-----------

.. inheritance-diagram:: Controller
    :parts: 1
    
.. autoclass:: Controller
    :show-inheritance:
    :members:
    :undoc-members:

Readable interface
------------------

.. inheritance-diagram:: Readable
    :parts: 1
    
.. autoclass:: Readable
    :show-inheritance:
    :members:
    :undoc-members:

Startable interface
-------------------

.. inheritance-diagram:: Startable
    :parts: 1
    
.. autoclass:: Startable
    :show-inheritance:
    :members:
    :undoc-members:

Stopable interface
-------------------

.. inheritance-diagram:: Stopable
    :parts: 1
    
.. autoclass:: Stopable
    :show-inheritance:
    :members:
    :undoc-members:

Pseudo interface
----------------

.. inheritance-diagram:: PseudoController
    :parts: 1
    
.. autoclass:: PseudoController
    :show-inheritance:
    :members:
    :undoc-members:
    
Motor Controller API
---------------------

.. inheritance-diagram:: MotorController
    :parts: 1
    
.. autoclass:: MotorController
    :show-inheritance:
    :members:
    :undoc-members:

Pseudo Motor Controller API
-----------------------------

.. inheritance-diagram:: PseudoMotorController
    :parts: 1
    
.. autoclass:: PseudoMotorController
    :show-inheritance:
    :members:
    :undoc-members:
    
Counter Timer Controller API
----------------------------

.. inheritance-diagram:: CounterTimerController
    :parts: 1
    
.. autoclass:: CounterTimerController
    :show-inheritance:
    :members:
    :undoc-members:

Pseudo Counter Controller API
-----------------------------

.. inheritance-diagram:: PseudoCounterController
    :parts: 1
    
.. autoclass:: PseudoCounterController
    :show-inheritance:
    :members:
    :undoc-members:

IO Register Controller API
----------------------------

.. inheritance-diagram:: IORegisterController
    :parts: 1
    
.. autoclass:: IORegisterController
    :show-inheritance:
    :members:
    :undoc-members:
